@@ -147,7 +147,6 @@ DCMI_ERROR_LIBRARY_NOT_FOUND = -99999
 ## Lib loading ##
 dcmiLib = None
 libLoadLock = threading.Lock()
-_dcmiLib_refcount = 0  # Incremented on each dcmiInit and decremented on dcmiShutdown
 
 
 ## Error Checking ##
@@ -210,7 +209,7 @@ class DCMIError(Exception):
 
 def dcmiExceptionClass(dcmiErrorCode):
     if dcmiErrorCode not in DCMIError._valClassMapping:
-        msg = f"DCMI erro code {dcmiErrorCode} is not valid"
+        msg = f"DCMI error code {dcmiErrorCode} is not valid"
         raise ValueError(msg)
     return DCMIError._valClassMapping[dcmiErrorCode]
 
@@ -720,7 +719,6 @@ def convertStrBytes(func):
         return res
 
     return wrapper
-    return func
 
 
 def _LoadDcmiLibrary():
@@ -730,8 +728,8 @@ def _LoadDcmiLibrary():
         try:
             if dcmiLib is None:
                 if sys.platform.startswith("win"):
-                    # DCMI is typically used on Linux, but for completeness
-                    # Windows support would require different path handling
+                    # DCMI is typically used on Linux, but for completeness,
+                    # Windows support would require different path handling.
                     raise DCMIError(DCMI_ERROR_LIBRARY_NOT_FOUND)
                 # Linux path
                 with contextlib.suppress(OSError):
@@ -751,21 +749,6 @@ def dcmi_init():
     ret = fn()
     _dcmiCheckReturn(ret)
 
-    # Atomically update refcount
-    global _dcmiLib_refcount
-    libLoadLock.acquire()
-    _dcmiLib_refcount += 1
-    libLoadLock.release()
-
-
-def dcmi_shutdown():
-    # Atomically update refcount
-    global _dcmiLib_refcount
-    libLoadLock.acquire()
-    if _dcmiLib_refcount > 0:
-        _dcmiLib_refcount -= 1
-    libLoadLock.release()
-
 
 def dcmi_get_card_list():
     c_card_num = c_int()
@@ -1115,12 +1098,13 @@ def dcmi_get_dcmi_version():
 
 
 def dcmi_get_cann_version():
-    cann_version = ""
     ascend_home_path = Path(
         os.getenv("ASCEND_HOME_PATH", "/usr/local/Ascend/ascend-toolkit/latest"),
     )
     if not ascend_home_path.exists():
-        return cann_version
+        return None
+
+    cann_version = ""
 
     for sub_dir in ascend_home_path.iterdir():
         if not sub_dir.is_dir():
@@ -1143,7 +1127,7 @@ def dcmi_get_cann_version():
                         cann_version = line.strip().split("=")[-1]
                         break
 
-    return cann_version
+    return cann_version if cann_version else None
 
 
 def dcmi_get_mainboard_id(card_id, device_id):
